src.MEDS\_tabular\_automl.scripts.launch\_xgboost
=================================================

.. automodule:: src.MEDS_tabular_automl.scripts.launch_xgboost







   .. rubric:: Functions

   .. autosummary::

      main





   .. rubric:: Classes

   .. autosummary::

      Iterator
      XGBoostModel
